#!/bin/bash
set -e

# Will copy the binary files under home directory
INSTALL_DIR=$HOME/.roomarranger

#-------------------
# Move binary files
#-------------------
SOURCE_DIR=rooarr-bin
mkdir -p $INSTALL_DIR
rm -rf $INSTALL_DIR/Help $INSTALL_DIR/icons $INSTALL_DIR/Language $INSTALL_DIR/textures $INSTALL_DIR/samples $INSTALL_DIR/swatches
rm -rf $INSTALL_DIR/imageformats $INSTALL_DIR/iconengines $INSTALL_DIR/platforms $INSTALL_DIR/printsupport $INSTALL_DIR/xcbglintegrations
mv -f $SOURCE_DIR/* $INSTALL_DIR
rmdir $SOURCE_DIR

#-------
# Icons
#-------
ICON_DIR=~/.local/share/icons/hicolor
DESKTOP_DIR=~/.local/share/applications
DESKTOP_FILE=$DESKTOP_DIR/roomarranger.desktop
MIME_DIR=~/.local/share/mime
MIME_ASSOC_FILE=~/.local/share/applications/mimeapps.list

# Copy icons
mkdir -p $ICON_DIR/16x16/apps
mkdir -p $ICON_DIR/32x32/apps
mkdir -p $ICON_DIR/48x48/apps
mkdir -p $ICON_DIR/64x64/apps
mkdir -p $ICON_DIR/128x128/apps
mkdir -p $ICON_DIR/256x256/apps
mkdir -p $ICON_DIR/512x512/apps
cp $INSTALL_DIR/icons/icon_16x16.png $ICON_DIR/16x16/apps/roomarranger-icon.png
cp $INSTALL_DIR/icons/icon_32x32.png $ICON_DIR/32x32/apps/roomarranger-icon.png
cp $INSTALL_DIR/icons/icon_48x48.png $ICON_DIR/48x48/apps/roomarranger-icon.png
cp $INSTALL_DIR/icons/icon_64x64.png $ICON_DIR/64x64/apps/roomarranger-icon.png
cp $INSTALL_DIR/icons/icon_128x128.png $ICON_DIR/128x128/apps/roomarranger-icon.png
cp $INSTALL_DIR/icons/icon_256x256.png $ICON_DIR/256x256/apps/roomarranger-icon.png
cp $INSTALL_DIR/icons/icon_512x512.png $ICON_DIR/512x512/apps/roomarranger-icon.png
mkdir -p $ICON_DIR/32x32/mimetypes
cp $INSTALL_DIR/icons/raFileIcon32.png $ICON_DIR/32x32/mimetypes/application-com.roomarranger.project.png
cp $INSTALL_DIR/icons/raFileObjectIcon32.png $ICON_DIR/32x32/mimetypes/application-com.roomarranger.object.png

# Create start script - before running the program, add program path to $LD_LIBRARY_PATH to find .so files
START_FILE=$INSTALL_DIR/rooarr_run.sh
echo '#!/bin/sh' >$START_FILE
echo 'LD_LIBRARY_PATH=$HOME/.roomarranger:$LD_LIBRARY_PATH ./RoomArranger "$@"' >>$START_FILE
chmod a+x $START_FILE

# Generate desktop shortcut
mkdir -p $DESKTOP_DIR
echo "[Desktop Entry]" >$DESKTOP_FILE
echo "Type=Application" >>$DESKTOP_FILE
echo "Exec=$START_FILE %f" >>$DESKTOP_FILE
echo "Path=$INSTALL_DIR" >>$DESKTOP_FILE
echo "Name=Room Arranger" >>$DESKTOP_FILE
echo "GenericName=Design your room, office, appartment, house." >>$DESKTOP_FILE
echo "Icon=roomarranger-icon" >>$DESKTOP_FILE
echo "Terminal=false" >>$DESKTOP_FILE
echo "Categories=Graphics;3D;Design" >>$DESKTOP_FILE
echo "MimeType=application/com.roomarranger.project;application/com.roomarranger.object;" >>$DESKTOP_FILE
chmod a+x $DESKTOP_FILE

# Also copy it to Desktop
USER_DESKTOP_DIR=$(xdg-user-dir DESKTOP)
if [ -z "$USER_DESKTOP_DIR" ]; then USER_DESKTOP_DIR=~/Desktop; fi
cp $DESKTOP_FILE $USER_DESKTOP_DIR/


# Generate mimetype
mkdir -p $MIME_DIR/packages
cp $INSTALL_DIR/raproject.xml $MIME_DIR/packages
if [ ! -f '$MIME_ASSOC_FILE' ]; then
  echo "[Added Associations]" >$MIME_ASSOC_FILE
fi
echo "application/com.roomarranger.project=roomarranger.desktop;" >>$MIME_ASSOC_FILE
echo "application/com.roomarranger.object=roomarranger.desktop;" >>$MIME_ASSOC_FILE
if which update-mime-database >/dev/null 2>&1 ; then update-mime-database $MIME_DIR; fi
if which update-icon-caches >/dev/null 2>&1 ; then update-icon-caches $ICON_DIR; fi

